@@ -3,7 +3,7 @@
 
 YearMonthSplit <- function(x, nThread = 1L, fy_month = 6L) {
   x_class <- supported_classes(class(x))
-  .check_input(x, as.IDate("1948-01-01"), as.IDate("2075-12-31"), nThread = nThread)
+  .check_input(x, as.IDate("1948-01-01"), as.IDate("2075-12-31"), nThread = nThread, xclass = x_class)
   .Call("C_YearMonthSplit", x, x_class, fy_month, nThread, PACKAGE = packageName())
 }
 
