@@ -18,7 +18,9 @@
 #' @export
 
 fast_as_idate <- function(x, incl_day = TRUE, check = 0L, nThread = 1L) {
-  .check_input(x, as.IDate("1948-01-01"), as.IDate("2075-12-31"), check = check, nThread = nThread)
+  .check_input(x, as.IDate("1948-01-01"), as.IDate("2075-12-31"), check = check, nThread = nThread,
+               # "character"
+               xclass = 5L)
   o <- .Call("C_fastIDate", x, incl_day, nThread, PACKAGE = packageName())
   class(o) <- c("IDate", "Date")
   o
