@@ -1,6 +1,6 @@
 library(grattanInflators)
 
-expect_equal(round(lf_inflator("2015-16", "2016-17"), 3), 1.015, tolerance = 0.001, scale = 1)
+expect_equal(round(lf_inflator("2015-16", "2016-17"), 3), 1.012, tolerance = 0.005, scale = 1)
 expect_equal(round(lf_inflator("2015-16", "2014-15"), 3), 0.979, tolerance = 0.001, scale = 1)
 x <- c("2015-01-01", "2015-16", "2014-01-01")
 expect_equal(lf_inflator(x, "2016-17"), 1 / lf_inflator("2016-17", x))
@@ -14,3 +14,8 @@ expect_equal(lf_inflator(from_i, to_i), lf_inflator(from_c, to_c))
 
 expect_equal(lf_inflator(c("2015-16", "2015-16"), from = NA_character_), c(NaN, NaN))
 
+lfi_series <- lfi_original()[date <= fast_as_idate("2024-03-03")]
+
+expect_warning(lf_inflator("2020-21", "2023-24", series = lfi_series))
+expect_message(lf_inflator("2020-21", "2023-24", series = lfi_series, check = -1L))
+
